# Welcome to fairdatanow


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Effective interdisciplinary cooperation in data science projects
requires smooth access to both data and code. And with the recent
development of two amazing open source frameworks (self hosted Nextcloud
for data storage and Jupyter notebooks for computing), we are now in a
position to actually make this happen. Recently our lab (the
Rijkserfgoedlaboratorium in Amsterdam) has installed a Nextcloud server
that gives our lab the possibility to share data files organized in
project folders with research partners. These can be accessed manually
via a web interface, but also programmatically with the webdav protocol!
With `fairdatanow` we want to learn how to easily find en download data
files from a Nextcloud storage directly in Jupyter notebooks in order to
explore them and create visualizations.

Under the hood the `fairdatanow` makes use of the Nextcloud Python
Framework [nc-py-api](https://pypi.org/project/nc-py-api) for
communication with the cloud server, and the powerful
[holoviz](https://holoviz.org) Python packages and for creating
interactive tables.

Although the package is still **under construction** it is already
available for installation from the python package index.
